==> kotlin-compiler-1.4.30-sources.jar: org/jetbrains/kotlin/diagnostics/DiagnosticFactoryWithPsiElement.java <==
/*
 * Copyright 2010-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.kotlin.diagnostics;

import com.intellij.openapi.util.TextRange;
import com.intellij.psi.PsiElement;

import java.util.List;

public abstract class DiagnosticFactoryWithPsiElement<E extends PsiElement, D extends Diagnostic> extends DiagnosticFactory<D> {
    protected final PositioningStrategy<? super E> positioningStrategy;

    public DiagnosticFactoryWithPsiElement(Severity severity, PositioningStrategy<? super E> positioningStrategy) {
        super(severity);
        this.positioningStrategy = positioningStrategy;
    }

    protected List<TextRange> getTextRanges(ParametrizedDiagnostic<E> diagnostic) {
        return positioningStrategy.markDiagnostic(diagnostic);
    }

    protected boolean isValid(ParametrizedDiagnostic<E> diagnostic) {
        return positioningStrategy.isValid(diagnostic.getPsiElement());
    }

    @SuppressWarnings("MethodOverloadsMethodOfSuperclass")
    @Deprecated
    // ABI-compatibility only (used in Android plugin)
    public D cast(Diagnostic d) {
        return super.cast(d);
    }
}

==> kotlin-compiler-31.6.1-sources.jar: org/jetbrains/kotlin/diagnostics/DiagnosticFactoryWithPsiElement.java <==
/*
 * Copyright 2010-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.kotlin.diagnostics;

import com.intellij.openapi.util.TextRange;
import com.intellij.psi.PsiElement;
import kotlin.DeprecationLevel;

import java.util.List;

public abstract class DiagnosticFactoryWithPsiElement<E extends PsiElement, D extends Diagnostic> extends DiagnosticFactory<D> {
    protected final PositioningStrategy<? super E> positioningStrategy;

    public DiagnosticFactoryWithPsiElement(Severity severity, PositioningStrategy<? super E> positioningStrategy) {
        super(severity);
        this.positioningStrategy = positioningStrategy;
    }

    protected List<TextRange> getTextRanges(ParametrizedDiagnostic<E> diagnostic) {
        // TODO: it's strange that java requires cast here, because ParametrizedDiagnostic<E> inherits DiagnosticMarker
        return positioningStrategy.markDiagnostic((DiagnosticMarker) diagnostic);
    }

    protected boolean isValid(ParametrizedDiagnostic<E> diagnostic) {
        return positioningStrategy.isValid(diagnostic.getPsiElement());
    }

    public PositioningStrategy<? super E> getPositioningStrategy() {
        return positioningStrategy;
    }

    @SuppressWarnings("MethodOverloadsMethodOfSuperclass")
    @Deprecated
    @kotlin.Deprecated(message = "Use `cast` from the superclass.", level = DeprecationLevel.HIDDEN)
    // ABI-compatibility only (used in Android plugin)
    public D cast(Diagnostic d) {
        return super.cast(d);
    }
}
